#!/bin/bash

DAEMON="/usr/sbin/tproxyd"
NAME="tproxyd"
DESC="Protocol multiplexer"
CONF_PATH="/etc/wildix"
SSL_PATH="${CONF_PATH}/ssl"
SSL_CRT="tproxy_w.crt"
SSL_KEY="tproxy_w.key"
SSL_CSR="tproxy_w.csr"
PID="/var/run/$NAME.pid"
#######
var="$(which openssl)"
days="180days"
oldlength="1024"
oldcipher="1"
##get crt dates
year2038problem=$($var x509 -in ${SSL_PATH}/${SSL_CRT} -noout -enddate | cut -d= -f2 | cut -d" " -f4)
if [ $year2038problem -ge 2038 ]; then
	limitdate="$(date +"%s")"
else
	limitdate="$(date -d "$($var x509 -in ${SSL_PATH}/${SSL_CRT} -noout -enddate | cut -d= -f 2) -$days" +"%s")"
fi

nowdate="$(date +"%s")"
##get crt length
crtlength="$($var x509 -in ${SSL_PATH}/${SSL_CRT} -text -noout | grep "Public-Key" | sed 's/[^0-9.]//g')"
##get crt cipher
crtcipher="$($var x509 -in ${SSL_PATH}/${SSL_CRT} -text -noout | grep "Signature Algorithm" | sed 's/[^0-9.]//g' | awk '{print $1; exit}')"


generate_crt(){

	pushd /tmp

	# generate private key
	echo generating private key
	openssl genrsa -out $SSL_KEY

	# generate certificate request
	echo generating certificate request
	openssl req -new -key $SSL_KEY -out $SSL_CSR -subj '/CN=pbx.wildix.com/O=WILDIX SRL/C=IT/emailAddress=support@wildix.com'

	# create self-signed certificate
	echo generating certificate
	openssl x509 -req -days 3650 -in $SSL_CSR -signkey $SSL_KEY -out $SSL_CRT

	mv $SSL_CRT $SSL_PATH/
	mv $SSL_KEY $SSL_PATH/
	rm $SSL_CSR

	popd

}

check_include_files(){

	touch /etc/wildix/tproxy_wms_include.conf
	touch /etc/wildix/tproxy_wms_protocols_include.conf

	chown wms:wms /etc/wildix/tproxy_wms_include.conf
	chown wms:wms /etc/wildix/tproxy_wms_protocols_include.conf

	chmod u=rw,g=rw,o= /etc/wildix/tproxy_wms_include.conf
	chmod u=rw,g=rw,o= /etc/wildix/tproxy_wms_protocols_include.conf

}



if [ ! -f ${SSL_PATH}/${SSL_CRT} ] || [ ! -f ${SSL_PATH}/${SSL_KEY} ] || [ $nowdate -ge $limitdate ] || [ $crtlength -le $oldlength ] || [ $crtcipher -eq $oldcipher ]; then
	generate_crt
fi
check_include_files

exit 0
